==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/DestinationRuleListFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface DestinationRuleListFluent<A extends DestinationRuleListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,DestinationRule item);
    public A setToItems(int index,DestinationRule item);
    public A addToItems(DestinationRule... items);
    public A addAllToItems(Collection<DestinationRule> items);
    public A removeFromItems(DestinationRule... items);
    public A removeAllFromItems(Collection<DestinationRule> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<DestinationRule> getItems();
    public List<DestinationRule> buildItems();
    public DestinationRule buildItem(int index);
    public DestinationRule buildFirstItem();
    public DestinationRule buildLastItem();
    public DestinationRule buildMatchingItem(Predicate<DestinationRuleBuilder> predicate);
    public A withItems(List<DestinationRule> items);
    public A withItems(DestinationRule... items);
    public Boolean hasItems();
    public DestinationRuleListFluent.ItemsNested<A> addNewItem();
    public DestinationRuleListFluent.ItemsNested<A> addNewItemLike(DestinationRule item);
    public DestinationRuleListFluent.ItemsNested<A> setNewItemLike(int index,DestinationRule item);
    public DestinationRuleListFluent.ItemsNested<A> editItem(int index);
    public DestinationRuleListFluent.ItemsNested<A> editFirstItem();
    public DestinationRuleListFluent.ItemsNested<A> editLastItem();
    public DestinationRuleListFluent.ItemsNested<A> editMatchingItem(Predicate<DestinationRuleBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,DestinationRuleFluent<DestinationRuleListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/DestinationRuleListFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface DestinationRuleListFluent<A extends DestinationRuleListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,DestinationRule item);
    public A setToItems(int index,DestinationRule item);
    public A addToItems(DestinationRule... items);
    public A addAllToItems(Collection<DestinationRule> items);
    public A removeFromItems(DestinationRule... items);
    public A removeAllFromItems(Collection<DestinationRule> items);
    public A removeMatchingFromItems(Predicate<DestinationRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<DestinationRule> getItems();
    public List<DestinationRule> buildItems();
    public DestinationRule buildItem(int index);
    public DestinationRule buildFirstItem();
    public DestinationRule buildLastItem();
    public DestinationRule buildMatchingItem(Predicate<DestinationRuleBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<DestinationRuleBuilder> predicate);
    public A withItems(List<DestinationRule> items);
    public A withItems(DestinationRule... items);
    public Boolean hasItems();
    public DestinationRuleListFluent.ItemsNested<A> addNewItem();
    public DestinationRuleListFluent.ItemsNested<A> addNewItemLike(DestinationRule item);
    public DestinationRuleListFluent.ItemsNested<A> setNewItemLike(int index,DestinationRule item);
    public DestinationRuleListFluent.ItemsNested<A> editItem(int index);
    public DestinationRuleListFluent.ItemsNested<A> editFirstItem();
    public DestinationRuleListFluent.ItemsNested<A> editLastItem();
    public DestinationRuleListFluent.ItemsNested<A> editMatchingItem(Predicate<DestinationRuleBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,DestinationRuleFluent<DestinationRuleListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
